@@ -1,19 +1,17 @@
 package AnyEvent::TLS::SNI;
-# ABSTRACT: adds Server Name Indication (SNI) support to AnyEvent::TLS client.
-$AnyEvent::TLS::SNI::VERSION = '0.01';
+# ABSTRACT: Adds Server Name Indication (SNI) support to AnyEvent::TLS client.
+$AnyEvent::TLS::SNI::VERSION = '0.02';
 
 use strict;
 use warnings;
 no warnings 'redefine';
 no strict 'refs';
+use AnyEvent::Socket;
 use AnyEvent::TLS;
 use Net::SSLeay;
 use Carp qw( croak );
 
-croak 'Client side SNI not supported for this openssl'
-    if Net::SSLeay::OPENSSL_VERSION_NUMBER() < 0x01000000;
-
-{
+{  
     my $old_ref = \&{ 'AnyEvent::TLS::new' };
     *{ 'AnyEvent::TLS::new' } = sub {
         my ( $class, %param ) = @_;
@@ -36,6 +34,8 @@ croak 'Client side SNI not supported for this openssl'
 
         if ( $mode eq 'connect' ) {
             if ( $self->{host_name} ) {
+                croak 'Client side SNI not supported for this openssl'
+                    if Net::SSLeay::OPENSSL_VERSION_NUMBER() < 0x01000000;
                 Net::SSLeay::set_tlsext_host_name( $session, $self->{host_name} );
             }
         }
@@ -54,32 +54,32 @@ __END__
 
 =head1 NAME
 
-AnyEvent::TLS::SNI - adds Server Name Indication (SNI) support to AnyEvent::TLS client.
+AnyEvent::TLS::SNI - Adds Server Name Indication (SNI) support to AnyEvent::TLS client.
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
-use AnyEvent::HTTP;
-use AnyEvent::TLS::SNI;
+    use AnyEvent::HTTP;
+    use AnyEvent::TLS::SNI;
 
-my $cv = AnyEvent->condvar;
-$cv->begin;
-AnyEvent::HTTP::http_get(
-    'https://sni.velox.ch/',
-    tls_ctx => {
-        verify => 1,
-        verify_peername => 'https',
-        host_name => 'sni.velox.ch'
-    },
-    sub {
-        printf "Body length = %d\n", length( shift );
-        $cv->end;
-    }
-);
-$cv->recv;
+    my $cv = AnyEvent->condvar;
+    $cv->begin;
+    AnyEvent::HTTP::http_get(
+        'https://sni.velox.ch/',
+        tls_ctx => {
+            verify => 1,
+            verify_peername => 'https',
+            host_name => 'sni.velox.ch'
+        },
+        sub {
+            printf "Body length = %d\n", length( shift );
+            $cv->end;
+        }
+    );
+    $cv->recv;
 
 =head1 AUTHOR
 
